__code__='GatU0D/[on&>$QoP(Q(,JX4o(JQ,\\RG7[qW<=#uP+WreskRL-DW%>uq8PFN?g"f:R;YUA-?i$Dkf/g7H+Xp<Oi,3bOhOU(tR9@jh;#KHir^PB76NSpYO<ff9J-+R.]ENOD\'VGT4BJFcCWWG_d$<RD3"#^.?!)<Pi"#^1@!ZhIA#4OV1$,@FoPCTuiVZ>l[:BR0hr"ec`^pARS!7(aR!5&S^$#lJ4:;!S^eq:^i^rm&nCG;iBC+o`i"\'(,c<=lA6L:%gTGX:PV=Up;(pFp8dV&69VYniYq<G:7PpuY*q(B[)q+heUDX?qE`@Z@TaU/oJjX"SNT"RHLUo;2j1@%ToR]b:Fq"^<F"WfGMV"gWKO*[t)sq,--lR3V@J;3Lp1nQ5UKHV]qKZl$q,+gJ"_@\'-k[>!EF)UYN"$G$43h*iiP\\k"anF(M.\'Dp;h&R7T`Gi*3^*2V2j*ElJT\\Lp0rBR@s$?PFuj+P`MPFt:Le3RHd4[qfU&"8CXEj&@Rg!18D`q9,T%uf[nZTP8oYjB.kC8?7.mHNj=fT@0CR&fBF#F-mt60oTr77X/Ci;Zf&`q+F<DeQ!uXV&8rQ*)Bjq`ZR;O"kgTia7[F<gbh/-r:)$fKp0HIQ4m^_MK2EdCMJp89f-r"6PV4(qW-BDT(m2^AjY[gq\\9g\':r2q<5EfojEhXh$tCYkjm`MRc\'3rrg\'2Zsg*q9r1knCHiZ;GinSUJ-ps*!:ondc(\\^3fRS#:;5s4[b\'kTqR>l@!\'c>KHbu]5b3\'A\'rhRZ;=cE3^g\\o[b8iomA04iI8<@[0]?3%)<0B@m&HMeL&l++]iM=(F\'?Z<66A]:PGL,2H/UG*Hg/):&i,-&5RY6@"=o-HG_h%peFL\\0Z;B2hEGY=?-)n1_2"1gVpYrbkW9XE3(:r-_EhAlk8Vf$^Y56lkS,D9GY/5?O:IPkMV>8"&r?I5G2Vm_>W;7\'@pDU@-_-W@GH\'6PScl`p&.&r3Xo0NP:nNQ#5cVdPh:n1>B?mVW\'q#^H_)_AOREEo9__HX)<TtJ;In>!3&]MdmdqOmq6-lF(\\Z[tQeZ)ck*i@L;iPKG/K4Z\\5?jNhNQT"3U4&+~>'



__code__='Gat=(s)6@U\'RuIZTe-\\a;V9W0GVC80KEGdQdkjd/+l/78X<N?l@?]gL?!C7J2Wq\\1Q-)lkg+W?(p6Y0[ZV=>ZL=A,1BA_PBI!PG!#\\O(=e+GM&`P3,V-B%qR70*\\`"umY_?mIuE3!R*br!fq48A?LE"#pP<!^$QE&%DVL#^@-S*8j>;k5d49/cgD0\\.!ToE!>_Di+9]"!\'^Y"!r*YkkC?V7Y5s(QGb%qh]PK@Tj1hb6T>^-4BF\\R2\'hASj*#pn\']_Vkf0-#4&ln74_/9O?!DSVqD("k9m_CuUf737q?rPCI2;E+aA8Sa(iN_1sV9t_-48<8D31W=\'/3\'9&g=-moS/sh)5!LI.P6!M^2-A.Dqi]#5DHDYC&CBok<O?]bS$Eia#!0PtjQ\\9d.Q==g6#WA8<l#68:YAL_9d@?o7,B]rm1-DfW-AAh575`9QS\'":6S?"X"V$4p-8[bafe?G9ZZ""\\/DP_3YAV8s?&in>h]_fKKoi=/.ME99]a65K33bBm8d)ur:G+LKj0lJST.$hi8Y[g*SchjPR?42?A*6THYMtUSLTh5%LS:,cr_PCAErj,R)i,.%L,pc\\^IY6RcEp[XQfRa4iAEAjV"1(atqc)^GdXJ^fDYVN^DHs]FS&CF_$]/c(88tB\\CjTdOY1ECZS^,\'fJZ%jF&oMtl2YPo=\\aLJu`nl03Qr(h+l=S2(P<;m!(hNO%8N<TD<2WF_Xg`2FPf\\&"jF^T@j3D1`B_T*sA+5NKIAmS)WjBoLP%aOCKQZ2-3,,=#G`SNi^L:0FRT,&A]BQ3dHR8QXkhOslBK%K<=/N1qc$:4/n(k`K^PDQuqtB!$n#N9tB).,N-`NC]-!=8^muOW^9fMU0f;HP<cEA]8(2e8!6?[d`6t<SSUV/YCW@M:-qE<#\'^P2M)hC;,]^Un)YB%APi],enJ`!YFHq[M-rZG#PXHZ!g.1,:?1L[Oan95J%3\\hEY6gT$_PInc+ggcAaKgDO?ceR3LTHaoP%W&$\'Cd\'aV5n\'?*\\l7cZeBf^\'KS&B,U.?>I(a_=Nh.h4-"2:h.s-Zn:DoDL,]YWZ@f[NGj>KQNJW3K8_rRB`(<_Ck3.\\::7?9nB4*:SF83r)iZiT9uGLL<D5&[MHf5B`69WQ,\\\\p2?!^LB;*Q~>'



__code__='Gas1]?ZX[c&Dr[^a"_9^-Dga8W)24CTe_:el#\\tW1+\'BP-uK4k@730q7=.ToA4`<:M5(AQ@AY^V,5iGY(jbSYkYl[?Mn%-MF165)g\\q(o=80>A@IA?)k)V@j^W>>Un,Ro(!=80%fU`r<$\'53`J/?\\l5oP819L&ui!S@N[!,MZg!k&-U!A4De#Ik1e*j>`k!O)rV&T@pCIDAL+*rp`qp^uH)J=cgJ#.t$4.H"383WIlFY\'[ohL0oel!j;X1aVdVWA-5S#&24$5X_/D3,Bb$q1JZJq*3R,VpN\\3r_YF8X\\j3Dt<^fhf*`X=pFhA@FRJ_9YZ]lT9@;*r</Xd-;!sW_T6NW8O>^C+9"urJg1\'m!+rsW)\\4(abS2W35<lu)2?\\="]G6rJ/nfS7@*s$lEp5(#&3[!qKCURkU@lq/:3Xic?F[V02$8p&B/X^&k-V+=4"SF:dDG4I#Z(?P27Wf#n;X5L&5cC2)jcW/VimIVbeMY$gX4,qY0N_1P>\\?qdD5dWs]F@9PS3E\\iH/`0?UZ1S"#mJGoX-S_fkI/h/2LegfGS)PpG3O?e]qdqN=RjI$]G=SE;_gX#?<,";D[Q!$_,<O\'8^lG0d-FlN+;a_7545H=rgXA4\\Y2;H+4EOQ1)$enkR#W2V0SaQ)X<.T8,g]DWfVu1<1lE&VKkY`&?Q^\\k+H(j,@Wdb^29Br7rbha%@FtMIo\\1ds^JWp?<&nTge\'qE]W:[(TL0IoP972Kj(+<1m=f`(\\6jM5.ZfBTFg<h,P4.E0f0?BtWJK$spH0sarRl\'QgqW@**\\%h%La$o_2j[#W;8qNEC>(8R]^50dVE^mr<\\?l/;\\NO.0bePekiLUJPUL^k%+DnaV7CV\\tr>fe:K^K?<(Fu[Nc%5R`&B,8Bka/#L+/Sj^:S&9VOUNTedRX"p.#k8C^"+lEXCa%MLWoB`(=[D&4V9=J=Cu)Z7C\'oAH6V(I<JaBXB<(+kNDZY=(:1(W?dtYq`Uo.j>W2OQEEAOSW`&$de_t_G-RtouX\'G/m+H?c.6FI`?Cd_Heo2=qAi]scmWhBAj9A01@<*qk/GeVBJMMo_J@<Q[r,+?Nd-`gk/~>'
